@@ -116,7 +116,7 @@ def plot_confusion_matrix(cm,
     cb.set_label('Accuracy per label')
 
     if figname is not None:
-        plt.tightlayout()
+        plt.tight_layout()
         fig.savefig(figname)
     else:
         plt.show()
